#!/usr/bin/env bash

function main()
{
  if [ ! -d "${HOME}/mnt" ]; then
    mkdir "${HOME}/mnt"
    mkdir "${HOME}/mnt/music"
    mkdir "${HOME}/mnt/photos"
    mkdir "${HOME}/mnt/video"
    mkdir "${HOME}/mnt/NAS"
  fi


  local auto_file="auto_nas_$(whoami)"

  # Make a file with settings for the NAS mounts
  if [ ! -f "/etc/${auto_file}" ]; then
    echo -n "Username for NAS: "
    read NAS_USERNAME
    echo -n "Password for NAS: "
    read -s NAS_PASSWORD
    echo 

    sed -e "s/\[\[USERNAME\]\]/${NAS_USERNAME}/" \
      -e "s/\[\[PASSWORD\]\]/${NAS_PASSWORD}/" \
      -e "s/\[\[UNAME\]\]/$(whoami)/" \
      < "${DOTFILES}/NAS_mounts/auto_nas" \
      | sudo tee "/etc/${auto_file}" \
      > /dev/null

    # The file contains a password, so make sure noone can read it
    sudo chmod 600 "/etc/${auto_file}"
  fi

  # Add reference to the new file to /etc/auto_master
  if ! grep "${auto_file}" < /etc/auto_master >/dev/null; then
    echo "/- ${auto_file} -nosuid" \
      | sudo tee -a /etc/auto_master \
      > /dev/null
  fi


  # Install automount fixing script
  # Automount is wonky under OSX and will mount directories as the 
  # first user who wants to use them.
  # In many cases, this is root, and then noone else can access it.
  # The following lines installs a script found at
  # https://github.com/scotartt/shell_scripts
  # which fixes this by remounting all mountpoints that have the wrong
  # owner every 15 seconds.

  local script="${HOME}/bin/fix_mounts.sh"

  local plist="org.autonomous.fixmounts.plist"
  local plistloc="/Library/LaunchDaemons/${plist}"

  # Copy and set up mount-fixing script
  if [ ! -f "${script}" ]; then
    sed -e "s/\[\[USERNAME\]\]/$(whoami)/" \
      < "${DOTFILES}/NAS_mounts/fix_mounts.sh" \
      > "${script}"
    chmod +x "${script}"
  fi

  # Install a launchd service to run it every 15 seconds
  if [ ! -f "${plistloc}" ]; then
    sed -e "s/\[\[USERNAME\]\]/$(whoami)/" \
      < "${DOTFILES}/NAS_mounts/${plist}" \
      | sudo tee "${plistloc}" \
      > /dev/null

    sudo chmod 644 "${plistloc}"

    sudo launchctl load "${plistloc}"
  fi
}

main "$@"
